/*
 * File      : board.c
 * This file is part of RT-Thread RTOS
 * COPYRIGHT (C) 2006, RT-Thread Development Team
 *
 * The license and distribution terms for this file may be
 * found in the file LICENSE in this distribution or at
 * http://www.rt-thread.org/license/LICENSE
 *
 * Change Logs:
 * Date           Author       Notes
 * 2017-07-24     Tanek        the first version
 */
#include <rthw.h>
#include <rtthread.h>
#include "board.h"

#if 0
/*========================================================*/ 

#define _SCB_BASE (0xE000E010UL)
#define _SYSTICK_CTRL (*(rt_uint32_t *)(_SCB_BASE + 0x0))
#define _SYSTICK_LOAD (*(rt_uint32_t *)(_SCB_BASE + 0x4))
#define _SYSTICK_VAL (*(rt_uint32_t *)(_SCB_BASE + 0x8))
#define _SYSTICK_CALIB (*(rt_uint32_t *)(_SCB_BASE + 0xC))
#define _SYSTICK_PRI (*(rt_uint8_t *)(0xE000ED23UL))


extern void SystemCoreClockUpdate(void);
extern uint32_t SystemCoreClock;


static uint32_t _SysTick_Config(rt_uint32_t ticks)
{
  if ((ticks - 1) > 0xFFFFFF)
{
return 1;
}

_SYSTICK_LOAD = ticks - 1;
_SYSTICK_PRI = 0xFF;
_SYSTICK_VAL = 0;
_SYSTICK_CTRL = 0x07;

return 0;
}
/*=====================================================*/
#endif



#if defined(RT_USING_USER_MAIN) && defined(RT_USING_HEAP)
#define RT_HEAP_SIZE 1024 * 4
static uint32_t rt_heap[RT_HEAP_SIZE];	// heap default size: 4K(1024 * 4)
RT_WEAK void *rt_heap_begin_get(void)
{
    return rt_heap;
}

RT_WEAK void *rt_heap_end_get(void)
{
    return rt_heap + RT_HEAP_SIZE;
}
#endif

/**
 * This function will initial your board.
 */
void rt_hw_board_init()
{	
#if 0 
  SystemCoreClockUpdate();
 _SysTick_Config(SystemCoreClock / RT_TICK_PER_SECOND);
#endif
	
	/* System Tick Configuration */
	
  SysTick_Config( SystemCoreClock / RT_TICK_PER_SECOND );

	LED_Init();
  rt_hw_usart_init();
	//uart_init(115200);

/* Call components board initial (use INIT_BOARD_EXPORT()) */
#ifdef RT_USING_COMPONENTS_INIT
    rt_components_board_init();
#endif
    
#if defined(RT_USING_CONSOLE) && defined(RT_USING_DEVICE)
	rt_console_set_device(RT_CONSOLE_DEVICE_NAME);
#endif
    
#if defined(RT_USING_USER_MAIN) && defined(RT_USING_HEAP)
    rt_system_heap_init(rt_heap_begin_get(), rt_heap_end_get());
#endif
}

void SysTick_Handler(void)
{
	/* enter interrupt */
	rt_interrupt_enter();

	rt_tick_increase();

	/* leave interrupt */
	rt_interrupt_leave();
}

/**
  * @brief  ӳ䴮DEBUG_USARTxrt_kprintf()
  *   NoteDEBUG_USARTxbsp_usart.hжĺ꣬Ĭʹô1
  * @param  strҪڵַ
  * @retval 
  *
  * @attention
  * 
  */
void rt_hw_console_output(const char *str)
{	
	/* ٽ */
    rt_enter_critical();

	/* ֱַ */
    while (*str!='\0')
	{
		/*  */
        if (*str=='\n')
		{
			USART_SendData(USART1, '\r'); 
			while (USART_GetFlagStatus(USART1, USART_FLAG_TXE) == RESET);
		}

		USART_SendData(USART1, *str++); 				
		while (USART_GetFlagStatus(USART1, USART_FLAG_TXE) == RESET);	
	}	

	/* ˳ٽ */
    rt_exit_critical();
}

